@@ -182,6 +182,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudformation
@@ -358,6 +360,9 @@ class PipelineDeployStackAction(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineDeployStackAction.add_to_deployment_role_policy)
+            check_type(argname="argument statement", value=statement, expected_type=type_hints["statement"])
         return typing.cast(None, jsii.invoke(self, "addToDeploymentRolePolicy", [statement]))
 
     @jsii.member(jsii_name="bind")
@@ -378,6 +383,10 @@ class PipelineDeployStackAction(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineDeployStackAction.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument stage", value=stage, expected_type=type_hints["stage"])
         options = aws_cdk.aws_codepipeline.ActionBindOptions(bucket=bucket, role=role)
 
         return typing.cast(aws_cdk.aws_codepipeline.ActionConfig, jsii.invoke(self, "bind", [scope, stage, options]))
@@ -391,7 +400,7 @@ class PipelineDeployStackAction(
         description: typing.Optional[builtins.str] = None,
         enabled: typing.Optional[builtins.bool] = None,
         event_bus: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        event_pattern: typing.Optional[aws_cdk.aws_events.EventPattern] = None,
+        event_pattern: typing.Optional[typing.Union[aws_cdk.aws_events.EventPattern, typing.Dict[str, typing.Any]]] = None,
         rule_name: typing.Optional[builtins.str] = None,
         schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
         targets: typing.Optional[typing.Sequence[aws_cdk.aws_events.IRuleTarget]] = None,
@@ -410,6 +419,10 @@ class PipelineDeployStackAction(
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineDeployStackAction.on_state_change)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         options = aws_cdk.aws_events.RuleProps(
             description=description,
             enabled=enabled,
@@ -577,6 +590,18 @@ class PipelineDeployStackActionProps:
                 admin_permissions=True
             ))
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PipelineDeployStackActionProps.__init__)
+            check_type(argname="argument admin_permissions", value=admin_permissions, expected_type=type_hints["admin_permissions"])
+            check_type(argname="argument input", value=input, expected_type=type_hints["input"])
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
+            check_type(argname="argument capabilities", value=capabilities, expected_type=type_hints["capabilities"])
+            check_type(argname="argument change_set_name", value=change_set_name, expected_type=type_hints["change_set_name"])
+            check_type(argname="argument create_change_set_action_name", value=create_change_set_action_name, expected_type=type_hints["create_change_set_action_name"])
+            check_type(argname="argument create_change_set_run_order", value=create_change_set_run_order, expected_type=type_hints["create_change_set_run_order"])
+            check_type(argname="argument execute_change_set_action_name", value=execute_change_set_action_name, expected_type=type_hints["execute_change_set_action_name"])
+            check_type(argname="argument execute_change_set_run_order", value=execute_change_set_run_order, expected_type=type_hints["execute_change_set_run_order"])
+            check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         self._values: typing.Dict[str, typing.Any] = {
             "admin_permissions": admin_permissions,
             "input": input,
